# autoESDA


[![image](https://img.shields.io/pypi/v/autoesda.svg)](https://pypi.python.org/pypi/autoesda)


**A Python package that automated the exploratory spatial data analysis (ESDA) process by summarising the results in an HTML report**


-   Free software: BSD license
-   Documentation: https://NicholasDeKock.github.io/autoesda
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
